package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````4!<``#0```"(D0````(`!30`(``)
M`"@`&P`:``$``'!<C```7(P``%R,```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$```````````````````!HC```:(P```4`````$```
M`0```,"-``#`G0``P)T``(@"``"<`@``!@`````0```"````R(T``,B=``#(
MG0``"`$```@!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DP(T`
M`,"=``#`G0``0`(``$`"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!0````#````1TY5`.5ZX]9!X4`=LH?FH-:#_Q%+@I%)!````!`````!
M````1TY5```````#`````@`````````1````2@````@````(`````9`0!"5`
M!(`H@``%H(90A("!``(+*`2,.(`208H```A*````2P```$X```!2````4P``
M`%P```!=````7@````````!@````80```&(```!C````9````&<`````````
M``````&O-.ANQ=\?SMY'+6M_FGPNQ9NV=E0\E"#_Y`[59-1\V7%8'.)'Q@%"
M^M>'K$OCP+KCDGQ8[Y=YPN4_+/JA;&"R`8MOF4_#FVL)0]9GK\QF0D75[(D'
M<-,S8MOM%8PES`TZEPM_J9R;OMI7&^"G`@IK&IY0H^#[20``````````````
M````````````G!$````````#``L```````"@`````````P`6`'`"````````
M`````!(```!>`@`````````````2````SP(`````````````$@```(X"````
M`````````"(```#U`@`````````````1````?`,`````````````$@```!``
M`````````````"````#_`0`````````````2````N@(`````````````$@``
M`.,!`````````````!(```#I```````````````2````$0,`````````````
M$0```,@"`````````````!(```!-`0`````````````2````^0$`````````
M````$@```(<``````````````!(```"D`@`````````````2````Y```````
M````````$@```+T!`````````````!(```"5`0`````````````2````_P(`
M````````````$@```-P!`````````````!(````Z`@`````````````2````
M/P$`````````````$@```,8``````````````!$````-`0`````````````2
M````8P``````````````%@```#$"`````````````!(```"``@``````````
M```1````>P$`````````````$@```*L!`````````````!(```!H`0``````
M```````2````L@(`````````````$@```,T!`````````````!(```!T`0``
M```````````2````"@(`````````````$@```!L!`````````````!(````!
M```````````````@````&0(`````````````$@```*8!`````````````!(`
M``#R`0`````````````2````A@$`````````````$0```%0`````````````
M`!(```"=`@`````````````2````E@``````````````$@```-8"````````
M`````!(```!"`@`````````````2````H@``````````````$@```#0!````
M`````````!(````$`@`````````````2````JP(`````````````$@```/H`
M`````````````!(```!&```````````````2````[@``````````````$@``
M`%T!`````````````!(```!0`@`````````````2````TP``````````````
M$@```(<"`````````````!(```#!`@`````````````2````ZP$`````````
M````$@```"`"`````````````!(```!V```````````````2````U`$`````
M````````$@```+,!`````````````!(```"W```````````````2````*P$`
M````````````$@```"P``````````````"````#W`@`````````````1````
M[0(`````````````$@```.<"`````````````!(```#$`0`````````````2
M````F0,``%R@````````$``7`(4#```X.0``/`$``!(`#0"]`P``5"\``/0&
M```2``T`:P(``(`4``#0`@``$@`-`$L#``!T(0``!````!(`#0!<`P``2*``
M```````0`!<`200``'@A``"0`@``$@`-`(<$``!(-@``\`(``!(`#0`U!```
M2*`````````0`!<`I`,```@D```P````$@`-`,H#``"@1P``*`$``!(`#0#B
M`P``9$H```0````1``\`$00``%R@````````$``7`!8$``!<H````````!``
M%P!!!```!"```%P````2``T`5@0``"0N```P`0``$@`-`&@$```D*P``H```
M`!(`#0!V!```Q"L``'0````2``T`U0,```"@````````$``6`+$#```X)```
MJ`$``!(`#0"1`P``2*`````````0`!8`!P0``$2@```$````$0`6`-L#``!0
M%P```````!(`#0!^!```"$<``)@````2``T`UP,```"@````````(``6`&H#
M````+@``)````!(`#0"8`P``7*`````````0`!<`\0,``&`@```4`0``$@`-
M`"L$``#(2```;`$``!(`#0`>!```X"4``$0%```2``T``%]?9VUO;E]S=&%R
M=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R
M5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4$Q?
M8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U
M8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S
M971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]F<F5E
M`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V
M`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S
M=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES
M;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``7U]S=&%C:U]C:&M?
M9F%I;`!E>&ET`&QS965K-C0`<F5A9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O
M<&5N-C0`<W1R<F-H<@!U;FQI;FL`;65M;6]V90!S=')T;VL`<W1R;&5N`')M
M9&ER`')E860`;6MD:7(`7U]V9G!R:6YT9E]C:&L`9V5T<&ED`%]?;'-T870V
M-%]T:6UE-C0`<F5A9&QI;FL`<F5A;&QO8P!?7W-P<FEN=&9?8VAK`%]?9G!R
M:6YT9E]C:&L`7U]L:6)C7W-T87)T7VUA:6X`7U]S=&%T-C1?=&EM938T`'-T
M9&5R<@!M96UC:'(`7U]C>&%?9FEN86QI>F4`<W1R8VAR`&UE;6-M<`!M96US
M970`;W!E;F1I<@!G971U:60`86-C97-S`&UE;6-P>0!S=')C;7``7U]E<G)N
M;U]L;V-A=&EO;@!A8F]R=`!S=')N8VUP`%]?96YV:7)O;@!?7W)E9VES=&5R
M7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P97)L+G-O+C4N,S@`;&EB
M8RYS;RXV`&QD+6QI;G5X+G-O+C,`<&%R7V-U<G)E;G1?97AE8P!?7V)S<U]S
M=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P
M`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`
M<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`7U]D871A7W-T87)T`%])3U]S=&1I
M;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!M>5]P87)?<&P`7V5N9`!?
M7V5N9%]?`'!A<E]I;FET7V5N=@!S:&%?9FEN86P`7U]B<W-?<W1A<G0`>'-?
M:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C
M;&5A;@!P87)?9&EE`'-H85]I;FET`%A37TEN=&5R;F%L<U]005)?0D]/5`!'
M3$E"0U\R+C0`1TQ)0D-?,BXS-``````````"``(``P`#``,``P`!``,``P`#
M``,`!``#``$``P`!``,``0`#``,``P`#``,``0`!``$``0`#``,``0`#``$`
M`P`#``,``P`!``$``P`#``,``0`!``,``0`#``,``0`!``,``P`!``$``0`!
M``,``0`#``,``P`"``$``P`#``$``0`!``,``P`#``,``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$````!``$`/0,``!`````@````%&EI#0``!`"=!`````````$``@`S`P``
M$``````````4:6D-```#`)T$```0````M)&6!@```@"G!````````,"=```7
M````Q)T``!<```#PGP``%P````2@```7````%*```!<````8H```%P```""@
M```7````)*```!<````HH```%P```"R@```7````,*```!<````XH```%P``
M`#R@```7````1*```!<```#(GP``%08``,R?```5"0``T)\``!4.``#4GP``
M%1```-B?```5&P``W)\``!,=``#@GP``%1\``.2?```5*```Z)\``!4L``#L
MGP``%38``/2?```50```^)\``!5%``#\GP``%48``-R>```6`P``X)X``!8$
M``#DG@``%@4``.B>```6!@``[)X``!8(``#PG@``%@H``/2>```6"P``^)X`
M`!8,``#\G@``%@T```"?```6#P``!)\``!81```(GP``%A(```R?```6$P``
M$)\``!84```4GP``%A4``!B?```6%@``')\``!87```@GP``%A@``"2?```6
M&0``*)\``!8:```LGP``%AP``#"?```6'@``-)\``!8@```XGP``%B$``#R?
M```6(@``0)\``!8C``!$GP``%B0``$B?```6)0``3)\``!8F``!0GP``%B<`
M`%2?```6*```6)\``!8I``!<GP``%BH``&"?```6*P``9)\``!8M``!HGP``
M%BX``&R?```6+P``<)\``!8P``!TGP``%C$``'B?```6,@``?)\``!8S``"`
MGP``%C0``(2?```6-0``B)\``!8W``",GP``%C@``)"?```6.0``E)\``!8Z
M``"8GP``%CL``)R?```6/```H)\``!8]``"DGP``%CX``*B?```6/P``K)\`
M`!9!``"PGP``%D(``+2?```60P``N)\``!9$``"\GP``%D<``,"?```62```
MQ)\``!9)```(0"WI>P$`ZPB`O>@$X"WE!."?Y0[@C^`(\+[E&(T```#&C^((
MRHSB&/V\Y0#&C^((RHSB$/V\Y0#&C^((RHSB"/V\Y0#&C^((RHSB`/V\Y0#&
MC^((RHSB^/R\Y0#&C^((RHSB\/R\Y0#&C^((RHSBZ/R\Y0#&C^((RHSBX/R\
MY0#&C^((RHSBV/R\Y0#&C^((RHSBT/R\Y0#&C^((RHSBR/R\Y0#&C^((RHSB
MP/R\Y0#&C^((RHSBN/R\Y0#&C^((RHSBL/R\Y0#&C^((RHSBJ/R\Y0#&C^((
MRHSBH/R\Y0#&C^((RHSBF/R\Y0#&C^((RHSBD/R\Y0#&C^((RHSBB/R\Y0#&
MC^((RHSB@/R\Y0#&C^((RHSB>/R\Y0#&C^((RHSB</R\Y0#&C^((RHSB:/R\
MY0#&C^((RHSB8/R\Y0#&C^((RHSB6/R\Y0#&C^((RHSB4/R\Y0#&C^((RHSB
M2/R\Y0#&C^((RHSB0/R\Y0#&C^((RHSB./R\Y0#&C^((RHSB,/R\Y0#&C^((
MRHSB*/R\Y0#&C^((RHSB(/R\Y0#&C^((RHSB&/R\Y0#&C^((RHSB$/R\Y0#&
MC^((RHSB"/R\Y0#&C^((RHSB`/R\Y0#&C^((RHSB^/N\Y0#&C^((RHSB\/N\
MY0#&C^((RHSBZ/N\Y0#&C^((RHSBX/N\Y0#&C^((RHSBV/N\Y0#&C^((RHSB
MT/N\Y0#&C^((RHSBR/N\Y0#&C^((RHSBP/N\Y0#&C^((RHSBN/N\Y0#&C^((
MRHSBL/N\Y0#&C^((RHSBJ/N\Y0#&C^((RHSBH/N\Y0#&C^((RHSBF/N\Y0#&
MC^((RHSBD/N\Y0#&C^((RHSBB/N\Y0#&C^((RHSB@/N\Y0#&C^((RHSB>/N\
MY0#&C^((RHSB</N\Y0#&C^((RHSB:/N\Y0#&C^((RHSB8/N\Y0#&C^((RHSB
M6/N\Y0#&C^((RHSB4/N\Y0#&C^((RHSB2/N\Y0'*H.-P0"WI#,!-X,@/C.5@
MPI_E8#*?Y2C03>(,P(_@'`"-Y1@0C>44((WE`S"<YQ@0C>(4((WB'`"-XCQ"
MG^4`,)/E)#"-Y0`PH..@___K+"*?Y01`C^`H,I_E`B"4YPP@C>4#,)3G`A"@
MX0,`H.$0,(WE4PT`ZPPRG^4#,)3G`%#3Y0``5>-1```*_#&?Y4H-`.L#,)_G
M'%"=Y0,@D.<$`(7BUC/2Y0<!<.,#,(/C`U"%XM8SPN5B``"*``&@X67__^O(
M$9_ER"&?Y0$0C^`"((_@`,"1Y1Q`G>48$)WE`0!4XP#@D>4`,*#A!`""Y:0!
MG^6D(9_E``"/X`(@C^``X(/E`1"#Z0P@@^54``#:!`!!X@S`@^($`8#@!."Q
MY03@K.4!`%#A^___&@-`A.(`$*#C:&&?Y0`0C>4$$8/G8!&?Y09@C^`,`);E
M!2"@X0$0C^!____K``!0XRD```I$49_E(&"-X@50C^`,`)7E*O__ZP80H.$`
M0*#A+`&?Y0``C^"K``#K``!0XR````H<,9_E`S"/X`P`D^4-___K9O__ZPPA
MG^7,,)_E`B"/X`,PDN<`()/E)#"=Y0(@,^``,*#C*@``&@0`H.$HT(WB<("]
MZ!K__^O<()_E`B"/X```4.,,`(+E'P``"O/^_^O(,)_E\0P`ZP,PG^<#,)#G
MOE;#Y:#__^H,`);E;___Z]+__^H(`)7E``!0XP$```JD"`#KV?__ZI0`G^4&
M$*#A``"/X'\``.L``%#C"`"%Y=+__PKU___J>#"?Y7@`G^4#,)3G``"/X`,0
MH.$,,(WE*O__ZP1`H..P___J`0"@XQ'__^O=_O_K+(H````!``#TB0``'`$`
M`"0!```(`0``P(H``/"*``#TB@``F#@``)@X``"`B@``?`D``%R*``"T-0``
M,(H``)R(``#HB0``7(D``*`T```8`0``?#8```"PH.,`X*#C!!"=Y`T@H.$$
M("WE!``MY1R@G^48,(_B`Z"*X``PH.,$,"WE#`"?Y0``FN>/_O_K-O__ZT2'
M```@`0``%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!W/[_ZBR'```4`0``+`"?
MY2PPG^4``(_@`S"/X```4^$@,)_E`S"/X![_+P$8()_E`C"3YP``4^,>_R\!
M$_\OX8"(``!\B```^(8``/P````X`)_E.#"?Y0``C^`#,(_@`#!#X*,?H.%#
M$8'@)#"?Y<$0L.$#,(_@'O\O`1@@G^4",)/G``!3XQ[_+P$3_R_A/(@``#B(
M``"HA@``*`$``$PPG^5,()_E`S"/X``PT^4"((_@``!3XQ[_+Q$X,)_E$$`M
MZ0,PDN<``%/C`@``"B@PG^4#`)_G5?[_Z\K__^L<,)_E`2"@XP,PC^``(,/E
M$("]Z.R'``!LA@``^````'R'``"LAP``T/__Z@'*H./P1RWI#,!-X.`/C.7(
M,)_E`(!0X@,PC^`K```*O""?Y0(PD^<`D)/E``!9XR@```H`4-CE`7"@X0``
M5>,]`%43`5"@$P!0H`,1```:`$"9Y0``5.,,```*"6"@X04@H.$($*#A!`"@
MX<S^_^L``%#C`@``&@4PU.<]`%/C"P``"@1`MN4``%3C\___&@0`H.'PA[WH
M"%"@X0$P]>4``%/C/0!3$_O__QH(4$7@YO__Z@E@1N`!4(7B1F&@X05`A.`$
M`*#A`&"'Y?"'O>@(0*#A[?__Z@E`H.'K___J^(4``"P!```!RJ#C$$`MZ0S`
M3>"`#XSEC""?Y8PPG^4"((_@>-!-X@,PDN<-$*#A`$"@X0`PD^5T,(WE`#"@
MXY#^_^L``%#C``"@$P0``!H0,)WE#SH#X@H*4^,!"5,3"@``"D@@G^5`,)_E
M`B"/X`,PDN<`()/E=#"=Y0(@,^``,*#C!P``&GC0C>(0@+WH`A"@XP0`H.%T
M_O_K$`]OX:`"H.'N___J"O[_ZQ"%`````0``Q(0```'*H./P0"WI#,!-X&@/
MC.5<(9_E7#&?Y0(@C^`#,)+GA-!-X@!@4.(`,)/E?#"-Y0`PH.,"```*`##6
MY0``4^,*```:,"&?Y2@QG^4"((_@`S"2YP`@D^5\,)WE`B`SX``PH.-!```:
MA-"-XO"`O>@(_O_K`$!0XO'__PH$`*#A6/[_ZP``4.,J```*$S#0Y1-0@.(N
M`%/C`@``&@$PU>4``%/C]/__"A,PT.4N`%/C)0``"@8`H.$._O_K`'"@X04`
MH.$+_O_K``"'X`(`@.+V_?_KI#"?Y0`@X.,#,(_@`1"@XP10C>4`8(WE`'"@
MX0_^_^L($(WB!P"@X9K]_^L!`'#C!P"@X0,```H8,)WE#SH#X@$)4^,2```*
MQ?W_ZP<`H.&H_?_K!`"@X2W^_^L``%#CU/__&@0`H.$X_O_K!@"@X:;]_^N]
M___J`3#5Y2X`4^/6__\:`C#5Y0``4^/%__\*TO__ZJ3__^OK___JJOW_ZV"$
M`````0``+(0``,0O```!RJ#C\$<MZ0S`3>#8#XSE`##1Y1`BG^4]`%/C##*?
MY0(@C^`!0*#A`S"2YP%`@0((T$WB`%"@X00`H.$`,)/E!#"-Y0`PH./)_?_K
M#1"@X=R!G^4(@(_@`&"@X04`H.$?___K`)!0XD````K`_?_K``!6X3<``)JX
M,9_E`'"=Y0.`F.<'<:#A`##5Y0``4^,]`%,3`3"@$P`PH`,%```*!3"@X0$@
M\^4``%+C/0!2$_O__QH%,$/@`@"&X@,`@.``8)CEF/W_ZP``4.,'`(;G%0``
M"@`@F.4%`*#A`3#0Y`<0DN<]`%/C``!3$P`PP>4&```*`2"!X@$PT.0"$*#A
M/0!3XP``4Q,!,,+D^?__&CTPH.,!(*#A`##!Y0$PU.0!,.+E``!3X_O__QH(
M(9_E^#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XS4``!H(T(WB\(>]Z`&0
M2>(!,-3D`3#IY0``4^/[__\:[O__ZL`PG^4#@)CG`'"8Y0`PE^4``%/C)```
M"@<PH.$$(+/E"1"@X0``4N,!D(GB^O__&@,0@>(!$:#AD#"?Y0,PC^``()/E
M``!2XP\``!H!(*#C`0"@X0`@@^57_?_K`*!0XM7__PH'$*#A"7&@X0<@H.$5
M_?_K`*"(Y0`PH.,`D(WE`9")X@DQBN>B___J!P"@X2[]_^L``%#C`*"@X0``
MB.7%__\*"7&@X?+__^H#D*#A"!"@X]___^H;_?_KU((````!``"@@@``+`$`
M`,"!``#$@@```<J@X_!!+>D,P$W@``",Y2``#.4!<*#A`!&?Y0`QG^4!VDWB
M"-!-X@$0C^`#,)'G`&"@X0$*C>($`(#B`#"3Y0`P@.4`,*#CV`"?Y02`C>+4
M()_E``"/X`@0H.$/_?_K`$!0X@<``-H(4(WB`3!$X@/`A>`$(%SE``!2XQ<`
M`!H``%/C%```&J`PG^7E"@#K`S"?YP<@H.$#`)#G!A"@X?O\_^N(()_E=#"?
MY0(@C^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@,^``,*#C$@``&@':C>((T(WB
M\(&]Z`-`H.$$(*#A+Q"@XP@`H.$\_?_K``!0X^/__PHX,)_ER0H`ZP,PG^<(
M(*#A`P"0YP80H.$$,*#A1/W_Z^'__^K-_/_KB(`````!``",+```_P\``"R!
M```$@```O(````'*H.,00"WI#,!-X.@/C.5T$)_E=#"?Y0$0C^!P()_E$-!-
MX@,PD><,,(WE`B"?YV`PG^5@$)_EJPH`ZP,PC^``0*#A`1"/X`(`D.<,()WE
M_/S_ZT0`G^5$,)_E``"?YT`@G^5`$)_E`S"/X`#`H.,``)3G`B"/X`$0C^`(
M$(WH!?W_ZQ#0C>(0@+WH7'\```0!``!4@```(&P``'`K```D@```4"X``'@6
M``!8*P``$$`MZ8P*`.LX0)_E.""?Y01`C^`T,)_E"-!-X@(@E.<$((WE`S"?
MYR00G^4#`)#G(#"?Y0$0C^`#,(_@"-"-XA!`O>C3_/_JM'X```0!``"L?P``
MT"H``'1K```!RJ#C<$`MZ0S`3>```(SE`<I,X@``C.4H``SEV""?Y=@PG^4"
MVDWB&-!-X@(@C^`#,)+G`AJ-XA00@>(`,)/E`#"!Y0`PH..@_/_KL,"?Y;`P
MG^4,P(_@#$"-X@%JC>*D()_E`S"/X`$0H.,08(;B`1"-Z`0`H.&I_/_K!`"@
MX0$JH.,&$*#A<OS_ZP!`4.(`4*"S"```N@$`A.)__/_K`%!0X@0```H$(*#A
M!A"@X43\_^L`,*#C!##%YTP@G^4X,)_E`B"/X`(:C>(#,)+G%!"!X@`@D^4`
M,)'E`B`SX``PH.,#```:!0"@X0+:C>(8T(WB<("]Z$3\_^L\?@````$``)0J
M``!X*@```1```*1]``"Y___J`<J@X_!/+>D,P$W@``",Y;``#.5$(I_E1#*?
MY4+=3>(,T$WB`B"/X`!@H.$T`I_E`S"2YT+-C>(0@(WB`4"@X0``C^`($*#A
M!,",X@`PD^4`,(SE`#"@X[C]_^LO$*#C`%"@X08`H.%>_/_K``!0XQ(```KP
M`9_E!A"@X0``C^!U_O_K!@"@X>`AG^70,9_E`B"/X$(=C>(#,)+G!!"!X@`@
MD^4`,)'E`B`SX``PH.-I```:0MV-X@S0C>+PC[WH!`"@X0C\_^ND$9_E`1"/
MX''\_^L`0%#BY?__"@`PU.60D9_EB*"-X@``4^,)D(_@!'!*XCL```H``%7C
M!```"@00H.$%`*#AT_O_ZP``4.,K```*!`"@X2S\_^L!,$#B`S"$X`,`5.$`
ML*#A`#"$,``0H#,!`(0R`P``.@@``.H#`%#A`!##Y0(```H!('/E+P!2X_G_
M_PH$`*#A&_S_ZP"PH.$&`*#A&/S_ZPL`@.`!`(#B`0I0X[W__RKX`)_E"3"@
MX0``C^`!*J#C`1"@XT$`C>D`0(WE!P"@X1K\_^L($*#A!P"@X:7[_^L``%#C
M`P``&F@P&N4/.@/B`@E3XQ4```JT$)_E``"@XP$0C^`Q_/_K`$!0XJ7__PH`
M,-3E``!3X\/__QH``%7C%@``"@`PU>4N`%/C`P``"H!`G^4!L*#C!$"/X-7_
M_^H!,-7E``!3X^K__PKW___J`1"@XP<`H.$9_/_K``!0X^3__QI0`)_E!Q"@
MX0``C^`&_O_K!P"@X:C[_^N.___J.$"?Y0&PH.,$0(_@P?__ZJ7[_^LL?0``
M``$``)@I``!H*0``P'P``"@I```,*0``?"@``"@H``#0)P``K"<``(`G```!
MRJ#C$$`MZ0S`3>#X#XSE+Q"@XP!`H.$!_/_K``!0XP%`@!($`*#A$$"]Z(K[
M_^H!RJ#C<$`MZ0S`3>```(SE&``,Y7`AG^5P,9_E`=I-X@(@C^`(T$WB`1J-
MX@,PDN<`8%#B!!"!X@`PD^4`,('E`#"@XR\```H`,-;E``!3XRP```JM^__K
M`2"`X@$*4N,`0*#A.```B@10C>(&$*#A!0"@X5W[_^L!,$3B`S"%X`4`4^$'
M``":`!"@XP(``.H%`%/A`1##Y0(```H!(%/D+P!2X_G__PHO$*#C!0"@X<_[
M_^L``%#C)0``"@4`4.$`,*"#`##`A04`H.%6^__KO""?Y;0PG^4"((_@`1J-
MX@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@XR(``!H!VHWB"-"-XG"`O>B(()_E
M?#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@,^``,*#C%```&F``G^4`
M`(_@`=J-X@C0C>)P0+WH-_O_Z@``H./>___J1""?Y3`PG^4"((_@`1J-X@,P
MDN<$$('B`""3Y0`PD>4"(#/@`#"@XR``GP4``(\`[/__"BK[_^MP>@````$`
M`+AY``"`>0``W"4``#1Y``"4)0```<J@XW!`+>D,P$W@Z`^,Y<0DG^7$-)_E
M`B"/X,!DG^4#,)+G"-!-XKA4G^4&8(_@#4"@X0`PD^4$,(WE`#"@XP50C^`$
M$*#A!@"@X:'\_^L``%#C#@``"HPTG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A
M@><``%+C\?__"@0P@^($()/E!""#Y```4N/[__\:Z___ZE1DG^4&8(_@!!"@
MX08`H.&+_/_K``!0XPX```HT-)_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G
M``!2X_'__PH$,(/B!""3Y00@@^0``%+C^___&NO__^H`9)_E!F"/X`00H.$&
M`*#A=?S_ZP``4.,.```*W#.?Y0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``
M4N/Q__\*!#"#X@0@D^4$((/D``!2X_O__QKK___JK&.?Y09@C^`$$*#A!@"@
MX5_\_^L``%#C#@``"H0SG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C
M\?__"@0P@^($()/E!""#Y```4N/[__\:Z___ZEACG^4&8(_@!!"@X08`H.%)
M_/_K``!0XPX```HL,Y_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'_
M_PH$,(/B!""3Y00@@^0``%+C^___&NO__^H$8Y_E!F"/X`00H.$&`*#A,_S_
MZP``4.,.```*U#*?Y0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*
M!#"#X@0@D^4$((/D``!2X_O__QKK___JL&*?Y09@C^`$$*#A!@"@X1W\_^L`
M`%#C#@``"GPRG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P
M@^($()/E!""#Y```4N/[__\:Z___ZEQBG^4&8(_@!!"@X08`H.$'_/_K``!0
MXPX```HD,I_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B
M!""3Y00@@^0``%+C^___&NO__^H(8I_E!F"/X`00H.$&`*#A\?O_ZP``4.,.
M```*S#&?Y0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@
MD^4$((/D``!2X_O__QKK___JM&&?Y09@C^`$$*#A!@"@X=O[_^L``%#C#@``
M"G0QG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E
M!""#Y```4N/[__\:Z___ZF!AG^4&8(_@!!"@X08`H.'%^__K``!0XPX```H<
M,9_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@
M@^0``%+C^___&NO__^H,`9_E!!"@X0``C^"P^__K`!!0X@(```KX`)_E``"/
MX'+\_^OP`)_E!!"@X0``C^"G^__K`!!0X@(```K<`)_E``"/X&G\_^O4`)_E
M!!"@X0``C^">^__K`!!0XA(```K``)_E``"/X&#\_^NX()_E9#"?Y0(@C^`#
M,)+G`""3Y00PG>4"(#/@`#"@XQ```!J8$)_EF`"?Y0$0C^```(_@"-"-XG!`
MO>A0_/_JA`"?Y000H.$``(_@A?O_ZP`04.+I__\*<`"?Y0``C^!'_/_KY?__
MZNSY_^O0>`````$``'`E``"H>```+`$``!`E``#`)```="0``"0D``#<(P``
M(",``#@C``#L(@``H"(``,PA``#X(0``S"$``.@A``#H(0``Y"$```@A``!P
M=```P"$``"0A``"0(0``%"$```'*H.,$X"WE#,!-X/`/C.5X()_E>#"?Y0(@
MC^!T`)_E#-!-X@,PDN<``(_@#1"@X0`PD^4$,(WE`#"@XU3[_^L``%#C!0``
M"@``T.4``%#C,`!0$P$`H`,``*`3`0`@XC0@G^4H,)_E`B"/X`,PDN<`()/E
M!#"=Y0(@,^``,*#C`0``&@S0C>($\)WDKOG_ZXQS`````0``="```#QS```!
MRJ#C#P`MZ03@+>4,P$W@\`^,Y4@`G^5($)_E``"/X`$0D.=`P)_E#-!-XCP@
MG^4,P(_@`!"1Y000C>4`$*#C%#"-X@`PC>4"$)SG$""=Y0``D>4!$*#CNOG_
MZ_\`H./$^?_KZ'(````!``#4<@``$`$```#`H./P1RWI`>B@XPS`3>`.X$S@
M`<I,X@``C.4.`%SA^___&C@`#N4!V$WB&-!-X@(0H.-PP9_E`!"-Y6P1G^4,
MP(_@`1"<YP'HC>(`(*#C`#"@XP`0D>44$([E`!"@XQ3@CN(`@*#ABOG_ZP%@
M4.(`<,'BQR^@X<<_)N`",%/@`SB@X2,XH.$","/@`C!3X`(@PN`#8%;@`G#'
MX```5^,W``"Z")&?Y0Q0C>(`$*#C!B"@X0<PH.$(`*#A`!"-Y73Y_^L!`''C
M`0!P`S(```H)(*#A!1"@X0@`H.$W^?_K`0!PXRD```H'`%#C'P``F@@`0.(`
M0)7@'```*K2@G^4*H(_@`@``Z@%`1.(%`%3A%@``.@@@H.,*$*#A!`"@X3OY
M_^L``%#C]O__&@5`1.`&`)3@Q!^GX'P@G^5L,)_E`B"/X`'(C>(#,)+G%,",
MX@`@D^4`,)SE`B`SX``PH.,0```:`=B-XAC0C>+PA[WH`6A6X@!PQ^(!`'?C
M`0AV`\G__QH``.#C`!"@X>G__^HH`)_E``"/X'O__^L@`)_E``"/X'C__^LB
M^?_K4'(````!```(``$`R'(``%!Q``"$'@``:!X```'*H.,00"WI#,!-X/@/
MC.7[^/_K]/C_ZP``4.,``)`5$("]Z`'*H./P0"WI#,!-X-`/C.7X()_E^&"?
MY?@PG^4"((_@'-!-X@,PDN<&8(_@`%"@X1`0C>(&`*#A`#"3Y10PC>4`,*#C
MDOK_ZP!`4.("```*`##4Y0``4^,.```:N""?Y;`PG^4"((_@`S"2YP`@D^44
M,)WE`B`SX``PH.,B```:F`"?Y040H.$``(_@'-"-XO!`O>A%^__J!0"@X2#Y
M_^L`<*#A!`"@X1WY_^L``(?@`@"`X@CY_^MD,)_E`"#@XP,PC^`8`(WI6#"?
MY0$0H.,#,(_@`%"-Y0!PH.$?^?_K1""?Y2PPG^4"((_@`S"2YP`@D^44,)WE
M`B`SX``PH.,'$*`!!@"@`=___PK.^/_KB'```!`>`````0``0'```+`=``"(
M'```?!P``+QO```!RJ#C\$\MZ0S`3>#@#HSE4,:?Y0"@H.$,P(_@##",X@<`
MD^C\T$WBD'"-X@<`A^@T)I_E-#:?Y0(@C^`#,)+G&&",X@`PD^7T,(WE`#"@
MXP\`MNBH0(WB!."@X0\`KN@#`);H,,",X@,`CN@'`)SHG%"-X@<`A>CT!9_E
M(("-X@``C^`($*#A-?K_Z^2UG^4+L(_@`&!0X@(```H`,-;E``!3XQ@!`!J`
M^/_K>?C_ZP``4.-Z```*`&"0Y0``5N-W```*!@"@X<GX_^N``*#A`0"`XK3X
M_^L`$-;E``!1XP!0H.$<`(WE"P``"HB5G^4)D(_@!0"@X0`0C>4),*#A`1"@
MXP`@X./(^/_K`1#VY0)0A>(``%'C]?__&EP%G^4``(_@`@``Z@0`M.4``%#C
M#0``"@@0H.$)^O_K`%!0XOC__PH`,-7E``!3X_7__PH]^O_K``!0X_+__PH%
M`*#A:OC_ZP!`4.(-```:!$"7Y```5.,*```*`##4Y0``4^/0```*!`"@X2_Z
M_^L``%#C]?__"@0`H.%<^/_K`$!0XO'__PH$`*#AD?C_ZQQ@G>4`<*#A!@"@
MX8WX_^L`<(?@`7N'X@1PA^('`*#A=OC_ZZPTG^4`(.#C`S"/X`@PC>6@-)_E
M`1"@XP,PC^`$,(WEE#2?Y0Q@C>4#,(_@`$"-Y0!0H.&)^/_K!QV@XP4`H.&/
M^/_K`0!PXP,``!J`^/_K`!"0Y1$`4>.L```:"!"@X04`H.&D^/_K`&!0XBT`
M``I())_E`#":Y0(0F^=`))_E``"1Y0(@C^`!$*#C`%"-Y8KX_^L`<*#C*"2?
MY?PSG^4"((_@`S"2YP`@D^7T,)WE`B`SX``PH./R```:!P"@X?S0C>+PC[WH
M'/C_ZP!@4.**```:!`"5Y```4.,)```*"!"@X:KY_^L`,%#B^/__"@`PT^4`
M`%/C\O__&@0`E>0``%#C]?__&@T`H.,R^/_KM&.?Y5,0H.,&8(_@`%"@X1P`
MC>5\___J,#"=Y0\Z`^(!"5/CS?__&CA`G>7G]__K``!4X<G__QHP,)WE@SN@
MX:,[H.$'#5/CQ/__&@<`H.$=^/_K"!"@X0!PH.%<`Y_E``"/X(;Y_^L`$%#B
M?```"@``FN6R^__K`)!0XG@```H)`*#A(OC_ZP,`4.,`0*#A#```FB@3G^4$
M`$#B``")X`$0C^"]]__K``!0XP4``!H$`%3CH```"@1`B>`%,%3E+P!3XYP`
M``KX`I_E"!"@X0``C^!J^?_K``!0XP,```H`,-#E,`!3XP``4Q,$```:`!"@
MXPD`H.'P]__K`$!0XED``!K`$I_EP`*?Y0$0C^```(_@(?K_Z_?W_^NP,I_E
ML"*?Y0,PC^`,,(WEJ#*?Y0(@C^"DHI_EI)*?Y:2"G^4$((WE`S"/X``@X.,!
M$*#C`%"-Y0J@C^`)D(_@"("/X`@`C>4'`*#A^/?_ZPX``.KS]__K`#"0Y1$`
M4^,0```:W??_ZP$0H.,!8(;@"C"@X00@H.$0D(WE#&"-Y0#`H.$@$8WH!P"@
MX>CW_^L'':#C!P"@X>[W_^L!`'#C`$"@X>K__PH%`*#AAO?_ZQ@"G^4'$*#A
M``"/X/#Y_^L'`*#A@O[_ZV?__^H#0*#A-/__ZL?W_^N``*#A`0"`XOS^_^JH
M(9_E`#":Y0(`F^?<(9_E``"0Y0(@C^`$$(WE`%"-Y0$0H./A]__K5?__ZF_^
M_^N\(9_E5#&?Y0(@C^`#,)+G`""3Y?0PG>4"(#/@`#"@XT@``!H&`*#A_-"-
MXO!/O>AR]__J`)":Y83__^KD_?_K`)!1X@"`H.&A__^Z"B!0X@"@H.,`,,GB
M!`"@X<"PC>(`H(WE@/?_ZP8@H.,+$*#A!`"@X4;W_^L&`%#C,@``&D`QG^7`
M()WE`P!2X9#__QJT(-OA,#&?Y0,`4N&,__\:,B!8X@`PR>($`*#AR&"-X@"@
MC>5L]__K*""@XP0`H.$&$*#A,O?_ZR@`4.,>```:^#"?Y0`@X.,#,(_@##"-
MY>PPG^4!$*#C`S"/X$@`C>G@,)_E!P"@X0,PC^``4(WE\*#-Y87W_^NA___J
M!$":Y0``5.-?__\*!`"@X7#W_^L#`%#C6___FJP0G^4$`$#B``"$X`$0C^`,
M]__K``!0XP20H`%3___J+_?_ZXP`G^4``(_@@?W_ZY1P```\;P````$``'P;
M``#D;@``,!P``)@;``!<&P``/!H``#`;```0`0``)!L```1M```P&@``C!H`
M`%0:``"\&```_!@``'P8``"T&@``%!@``-P9``#<&0``@!H``.@7``!(%P``
M2!@``%QJ````0T%#2$4``-`8```L%@``Z!<``)@7``"$%P```<J@XW!`+>D,
MP$W@Z`^,Y7@2G^5X(I_E`1"/X`(@D><(T$WB;#*?Y0`@DN4$((WE`""@XP,P
MG^?N!`#K`T"0YU0"G^5H,-3E#5"@X0``C^!I,,3E!1"@X83X_^L``%#C`@``
M"@`PT.4Q`%/C;0``"LC[_^LD,I_EW@0`ZP,PG^<#0)#G&!*?Y00`H.$!$(_@
M`S"@XP$@H.,,]__K`$!0X@X```H0()3E^#&?Y0`0DN4#,)_G\"&?Y<X$`.L"
M((_@`&"@X0,`D.?E]O_K$#"4Y0`0D^4(,)'E`043XUT``!K(,9_ER!&?Y0,P
MG^?!!`#K`2"@XP!@H.$!$(_@`P"0YP,PH./Q]O_K`$!0X@L```J@`9_E!1"@
MX0``C^!3^/_K`"!0XD,```J,,9_E$!"4Y0,PG^<`$)'E`P"6Y\CV_^MX,9_E
MJP0`ZP,PG^=P$9_E`V"0YP!`H.$!$(_@`2"@XP8`H.'N]O_K6"&?Y0(@C^``
M$*#A!@"@X;GV_^M(,9_E2`&?Y0,PG^<`(*#C`S"4YP40H.$``(_@:2##Y3/X
M_^LL49_E!5"/X```4.,`0*#A"`"%Y1(```H'':#C!`"@X>;V_^L!((#B$0!0
MXP$`4A,`,*#A)0``BO@@G^6P,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C
M&P``&@C0C>)P@+WH!`"5Y;_]_^L``%#C`$"@X0@`A>7F__\:N`"?Y0``C^#'
M]O_K`3#0Y0``4^.3__\*C?__ZJ`PG^40()3E`S"/X`0PD^4``)+E`!"3Y5[Y
M_^NY___JA#"?Y0,PG^<#`);GQO;_ZYS__^IM]O_K<""?Y7``G^4"((_@!""2
MY0``C^``$)+E!""@X:WV_^MH:`````$``%AI```0%0``$&D``*06``#<:```
M>!8``*1H``!$%@``_!,``%QH``!$:```Z!4``.P5```(:```=!,``%AH``"@
M9@``0!4``+QG```P9P``A&<```05```!RJ#C,$`MZ0S`3>#H#XSE#"&?Y0PQ
MG^4"((_@`$"@X00!G^4#,)+G#-!-X@T0H.$``(_@`#"3Y00PC>4`,*#CSO?_
MZP`P4.(*```*`##3Y0``4^,P`%,3`3"@`P`PH!,!,"/B``!4XP`PH`,!,`,2
M``!3XPH``!JP()_EI#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XR```!H,
MT(WB,("]Z``PU.4``%/C\?__"@0`H.&1^O_K+Q"@XP!0H.&+]O_K``!0XP%0
M@!(%`*#A%?;_ZU@0G^4$(*#C`1"/X(_V_^L``%#CXO__&D0@G^4P,)_E`B"/
MX`,PDN<`()/E!#"=Y0(@,^``,*#C`P``&@0`H.$,T(WB,$"]Z/WW_^H$]O_K
M>&4````!``!8$@``$&4``'02``"<9`````````'*H./P3RWI#,!-X$`-C.5<
M[)_E7#R?Y0[@C^"GWTWB`S">YQ`@C>(`$*#A0,"`XH!0@.(`,)/EE#*-Y0`P
MH.,"`*#A`$"@XP1@'.4(<!SE)C2@X6?H)^#_/`/B)CR#X2[DH.$&A*#A!CR#
MX?_LSN/_:`CB",",XF?D+N`&,(/A!0!<X0#@@.4$0(#E"#"`Y0Q`@.40`(#B
MZO__&H(_@N($,(WEB#"=Y1C@C>(<H)WE"!"-Y7B`G>5\()WE&+"=Y8!PG>6$
M8)WEC,"=Y1!0G>440)WE#@"@X0,0H.$,X(WE`*"-Y0$``.H)L*#A`#"-Y0$P
MH.$\X)#E.!"0Y0B0L.4`H*#C"1`AX`@0(>`'@*#A`W"@X00PD.4%$"'@`^`N
MX`+@+N`$X"[@!B"@X0Q@H.&ASZ#ACL",X0$0D>`,$('A!,"=Y0!`G>4``%SA
M"U"@X0K`H.%TH(#E<!"`Y>'__QH($)WE#."=Y0"`D>4(.Y_E`0B1Z0@@'N4@
M0)'EJ&V@X1!PD>48D)'E`R"2X(!BAN$$()+@B&*&X0S`D>4"8);@"2`GX"M1
MH.$+(`+@"2`BX`Q?A>$"8);@"U^%X1@@G>4HP:#A`,^,X04`)^`#()+@"```
MX`D@DN`'`"#@",^,X0``DN`(()[E#$`EX`,@DN`&0`3@!4`DX`<@DN#F#8#@
M!""2X.!-@N`0()[E`R"2X`4@DN!F42S@`%`%X`Q0)>`%()+@&%">Y6`!H.$#
M4)7@#,"5X&91(.`$4`7@9E$EX.0M@N`%P)S@XEV,X"#`GN4#P)S@9L&,X&1A
M(.`"8`;@`&`FX`;`G.`H8)[E8B&@X0-@EN```);@9&$BX`5@!N!D82;@Y<V,
MX`8`D.#L;8#@,`">Y0,`D.!D`8#@94$BX`Q`!.`"0"3@!`"0X#A`GN5LP:#A
M`T"4X`(@E.!E02S@!D`$X&5!).#F#8#@!""2X.!-@N!`()[E`R"2X&4A@N!F
M42S@`%`%X`Q0)>`%()+@2%">Y6`!H.$#4)7@#,"5X&91(.`$4`7@9E$EX.0M
M@N`%P)S@XEV,X%#`GN4#P)S@9L&,X&1A(.`"8`;@`&`FX`;`G.!88)[E8B&@
MX0-@EN```);@9&$BX`5@!N!D82;@Y<V,X`8`D.#L;8#@8`">Y0,`D.!D`8#@
M94$BX`Q`!.`"0"3@!`"0X&A`GN5LP:#A`T"4X`(@E.!E02S@!D`$X&5!).#F
M#8#@!""2X.!-@N!P()[E`R"2X&4A@N!F42S@`%`%X`Q0)>`%()+@>%">Y6`!
MH.$#4)7@#,"5X&91(.`$4`7@9E$EX.0M@N`%P)S@XEV,X(#`GN4#P)S@9L&,
MX&1A(.`"8`;@`&`FX`;`G.#E;8S@B,">Y6(AH.$#P)S@``"<X&3!(N`%P`S@
M9,$LX`P`D.#FS8#@D`">Y0,PD.!E`2+@!@``X`(`(.!D,8/@`#"3X.RM@^"8
M`)[E+#B?Y69AH.$#`)#@H$">Y0(@D.!E`2;@#``@X``@DN`#`)3@90&`X.I-
M@N"H4)[E;"$FX`H@(N`"`)#@:B&@X0-0E>"PH)[E!E"5X&QA(N`$8";@Y`V`
MX`90E>`#8)K@;&&&X+B@GN7@S87@9%$BX`!0)>`%8);@8`&@X0-0FN`"4)7@
MP*">Y>PMAN!D82#@#&`FX`90E>`#8)K@9&&&X,B@GN5L02#@`D`DX.)=A>`$
M8);@8B&@X0-`FN```)3@T*">Y6Q!(N`%0"3@!$"0X`,`FN#E;8;@V*">Y6P!
M@.!EP2+@!L`LX.9-A.`,`)#@9F&@X0/`FN`"()S@X*">Y67!)N`$P"S@#,"2
MX`,@FN#D#8#@Z*">Y64A@N!D42;@`%`EX.#-C.`%()+@8`&@X0-0FN`&4)7@
M^*">Y?!@GN5DX2#@#.`NX.PM@N`.X)7@XEV.X`-@EN!LX2#@9$&&X`+@+N`.
MX)3@8B&@X0-`FN``0)3@&&&=Y6P!(N`%`"#@Y>V.X```E.`#8);@[DV`X&S!
MAN!E`2+@(&&=Y0X`(.```)S@;N&@X0-@EN`"();@9<$NX"AAG>4$P"S@Y`V`
MX`S`DN`#();@92&"X#!AG>7@78S@9,$NX`#`+.`,P)+@8`&@X0-@EN#E+8S@
M#N"6X&3!(.`X89WE!<`LX`S`GN`#X);@9.&.X$!AG>5E02#@`D`DX.+-C.`$
MX)[@8B&@X0-@EN```);@94$BX$AAG>4,0"3@[.V.X%"AG>4$0)#@`P"6X.PU
MG^5L82+@90&`X`Y@)N!N4:#A[DV$X`9@D.!LX87A`P":X`(`D.!8H9WEY"V&
MX`3@#N!L807@!N".X0[@D.`#H)K@9`&%X61A!>!LP8K@`@``X&"AG>4&`(#A
MXNV.X`P`D.!B(:#A`\":X`7`G.!D48+A9&$"X&BAG>4.4`7@!E"%X>X-@.`,
M4)7@`Z":X&[!@N%N80+@9$&*X`#`#.!PH9WE!L",X>!=A>`$0)S@8`&@X0/`
MFN`"P)S@Y2V$X&Y!@.%N80#@>*&=Y05`!.`&0(3A#$"4X`.@FN!EP8#A96$`
MX&[ABN`"P`S@@*&=Y0;`C.'B383@#N"<X&(AH.$#P)K@`,"<X.0-CN!EX8+A
M96$"X(BAG>4$X`[@!N".X0S@GN`#H)K@9,&"X61A`N!E48K@`,`,X)"AG>4&
MP(SAX.V.X`50G.!@`:#A`\":X`+`G.#N+87@9%&`X61A`."8H9WE#E`%X`90
MA>$,4)7@`Z":X&[!@.%N80#@9$&*X`+`#."@H9WE!L",X>)=A>`$0)S@8B&@
MX0/`FN``P)S@Y0V$X&Y!@N%N80+@J*&=Y05`!.`&0(3A#$"4X`.@FN!EP8+A
M96$"X&[ABN``P`S@L*&=Y0;`C.'@383@#N"<X&`!H.$#P)K@`L"<X.0MCN!E
MX8#A96$`X+BAG>4$X`[@!N".X0S@GN`#H)K@9,&`X61A`.!E48K@`L`,X,"A
MG>4&P(SAXNV.X`50G.!B(:#A`\":X`#`G.#N#87@9%&"X<BAG>5D80+@#E`%
MX`90A>$,4)7@`Z":X&[!@N%N80+@9$&*X`#`#.#0H9WE!L",X>!=A>`$0)S@
M8`&@X0/`FN``8*#C`L"<X.4MA.!N08#A!4`$X`1@@>4,8('E%&"!Y1Q@@>5N
M80#@V*&=Y09`A.$,0)3@9<&`X0.@FN!E80#@`L`,X&[ABN`&P(SAX*&=Y>)-
MA.`.P)S@8B&@X>3MC.`#H)K@9<&"X65A`N```)K@!,`,X.BAG>4&P(SA`,"<
MX`.@FN!D`8+AZ#*?Y61A`N!E48K@#@``X/"AG>4&`(#A[LV,X`4`D.!NX:#A
M`U":X`)0E>#X89WE9"$NX`P@(N#L#8#@`B"5X`-@EN#@78+@9$&&X&PA+N``
M8IWE`"`BX`(@E.!@`:#A`T"6X`Y`E.`(8IWE;.$@X`7@+N`.X)3@`T"6X.4M
M@N`08IWE;$&$X&7!(.`"P"S@XNV.X`S`E.!B(:#A`T"6X`!`E.`88IWE90$B
MX`X`(.#NS8S@``"4X`-`EN!E083@(&*=Y>Q=@.!N`2+@#``@X```E.!LP:#A
M`T"6X`)`E.`H8IWE;B$LX`4@(N#E#8#@`B"4X`-@EN#@38+@;N&&X&4A+.`P
M8IWE`"`BX`(@GN!@`:#A`^"6X`S@GN`X8IWE9<$@X`3`+.#D+8+@#,">X`/@
MEN!EX8[@0&*=Y>)=C.!DP2#@`L`LX`S`GN!B(:#A`^"6X`#@GN!(8IWE9`$B
MX`4`(.#ES8S@``">X`/@EN!DX8[@4&*=Y>Q-@.!E`2+@#``@X```GN!LP:#A
M`^"6X`+@GN!88IWE92$LX`0@(N#D#8#@`B">X`/@EN!EX8[@8&*=Y>!=@N!D
M(2S@`"`BX`(@GN!@`:#A`^"6X`S@GN!H8IWE9,$@X`7`+.#E+8+@#,">X`/@
MEN!DX8[@<&*=Y>)-C.!EP2#@`L`LX`S`GN!B(:#A`^"6X`#@GN!X8IWE90$B
MX`0`(.```)[@`^"6X.3-C.!EX8[@9&$BX(!2G>4,8";@[`V`X`;@GN!LP:#A
M`U"5X`(@E>!D82S@B%*=Y0!@)N`&()+@`S"5X.#MCN!@D8G@"#"3X&`!+.`.
M`"#@9#&#X``PD^#N+8+@XCV#X&YQA^`+()+@(`"1Y1B0@>40<('E`#"!Y0@@
M@>50()_E.#"?Y0(@C^``P)S@`&"@XR#`@>4D8('E`S"2YP`@D^64,IWE`B`S
MX``PH.,!```:I]^-XO"/O>C@\O_K.&0````!``"9>8):H>O9;MR\&X_6P6+*
M%%@```'*H.-P0"WI#,!-X/`/C.6``*#C]_+_ZU!0C^+00,7A`""@X_!`P.%(
M4(_BT$#%X7@@@.7X0,#A0%"/XM!`Q>'P0<#A/%"/XM!`Q>'X0<#A.%"/XM!`
MQ>'P0L#A`$"@XP!0H./X0L#A\$/`X7"`O>@!(T5G`````(FKS>\`````_MRZ
MF`````!V5#(0`````/#ATL,``````<J@X_!'+>D,P$W@X`^,Y2@PD.4"8*#A
MAL&#X"P@D.4#`%SA`#"@XP(@T^``4*#A,""0Y0%`H.$T$)#EQ@^@X0$``"H!
M()+B`!"AXBPPA>6F/J#A@#&#X0(PD^"@'J'@>`"5Y2C`A>4``%#C.("%`C`P
MA>4T$(7E%@``&C\`5N,F``#:0&!&XB:3H.$!<(GB!W.$X`00H.%`(*#C"`"@
MX7CR_^M`0(3B!0"@X8G\_^L'`%3A]O__&@F=:>`)8X;@!B"@X0<0H.$(`*#A
M;?+_ZWA@A>7PA[WH0'!@X@8`5^$&<*"A.("%X@``B.`'(*#A!!"@X6/R_^MX
M,)7E`S"'X$``4^-X,(7E\(>]&`4`H.$'8$;@!T"$X&[\_^O6___J!'"@X>7_
M_^H!RJ#C\$$MZ0S`3>#H#XSE*#"1Y0%`H.%C*"/@,!"1Y2(DH.'_+,+C8W0B
MX&$H(>"C,:#A(B2@X3\P`^+_+,+C860BX`$0@^(X@(3B?R#@XS@`4>,`4*#A
M`R#(YST``-I`(&'B`0"(X``0H..>\O_K!`"@X4W\_^LX(*#C`!"@XP@`H.&8
M\O_K!`"@X7!@A.5T<(3E1?S_ZP,PU.4`,,7ELC#4X0$PQ>4`,)3E!`"@X2,T
MH.$",,7E`#"4Y0,PQ>4+,-3E!##%Y;HPU.$%,,7E"#"4Y2,TH.$&,,7E"#"4
MY0<PQ>43,-3E"##%Y;(QU.$),,7E$#"4Y2,TH.$*,,7E$#"4Y0LPQ>4;,-3E
M###%Y;HQU.$-,,7E&#"4Y2,TH.$.,,7E&#"4Y0\PQ>4C,-3E$##%Y;(RU.$1
M,,7E(#"4Y2,TH.$2,,7E(#"4Y1,PQ>7P0;WH_O'_Z@$`B.`X(&'B`!"@XV#R
M_^O&___J````````````````#PK@XQ_P0.((,)_E`S"/X``PD^4(\O_JL%4`
M``A`+>D(@+WH`0`"`#X```!!````#````$$````1````00```"<```!!````
M-@```$$````#````00````8```!!````%0```$$````/````00````X```!!
M````)@```$$````3````00```"D```!!`````@```$$````9````00````H`
M``!!````"P```$$``````````````"5S+R5S````+W!R;V,O<V5L9B]E>&4`
M`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ
M0D]/5``````O<')O8R\E:2\E<P!E>&4`+@```%!!4E]414U0`````%!!4E]0
M4D]'3D%-10`````Z````)7,E<R5S```O````4$523#5,24(`````4$523$Q)
M0@!015),-4]05`````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4```!005)?
M1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)
M4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````,0```&QS
M965K(&9A:6QE9`````!R96%D(&9A:6QE9`!,1%],24)205)97U!!5$@`4UE3
M5$5-```E,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI
M"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE
M87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``4$%4
M2`````!P87)L`````"YP87(`````<VAO<G0@<F5A9```)7,E<V-A8VAE+25S
M)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S`````!@```!P
M97)L`````#````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`V,P```%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R
M<FYO/25I*0H`````+64``"TM``!54T52`````%5315).04U%`````%1%35!$
M25(`5$U0`"]T;7``````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D
M,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S
M:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?
M;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?
M34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@
M("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-
M04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM
M>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@
M)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@
M+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@
M:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P
M*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK
M7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD
M97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D
M:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A
M<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP
M(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD
M:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII
M9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$
M25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)
M6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D
M=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE
M(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<
M(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@
M97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D
M=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N
M86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q
M6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z
M.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A
M;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH
M/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@
M("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD[
M"E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G
M;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@
M)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P
M<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER
M97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN
M9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S
M*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@
M4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#
M04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD[
M"FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@
M>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*
M?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?
M1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP
M86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)
M3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,
M15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L
M("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H
M92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)
M3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^
M('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E
M;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH
M/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA
M;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS
M=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@
M)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[
M)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN
M9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H
M)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP
M9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H
M+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS
M965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@
M/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*
M)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A
M=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE
M(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL
M960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^
M("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR
M97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S
M<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE
M=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("10
M2UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%
M('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*
M?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@
M(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U
M;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!
M4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET
M>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H
M"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L
M;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'
M5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD
M14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@
M;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H
M0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ
M*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*
M96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q
M("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I
M('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U
M:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B
M/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D
M(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]
M"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2![
M"F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%2
M1U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70[
M"GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I
M('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G
M/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D
M<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q
M6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T
M85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O
M;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS
M.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ
M("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D
M<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I
M;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID
M:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E
M<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I
M(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?
M0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U12
M54Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D
M;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY
M("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI
M('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX[
M"GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*
M?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_
M.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*
M?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER
M92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E
M<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R
M"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO
M?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T
M96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H
M)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME
M>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF
M("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M
M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D
M97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE
M>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*
M:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D
M,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N
M86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H
M<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E
M9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92![
M"FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT
M(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I
M.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N
M=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C
M:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L
M($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I
M+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@
M)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z
M:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T
M(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP
M<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE
M7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@
M)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R
M.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M
M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*
M)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N
M9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP
M0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L
M;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-
M04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A
M:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*
M?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G
M;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N
M($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@
M9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E
M=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E
M861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z
M.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T
M<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A
M8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE
M;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M
M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO
M/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=
M*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE
M(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A
M8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M
M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T
M7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E
M<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A
M8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@
M=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@
M?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A
M;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"
M=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R
M92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS
M8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A
M<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N
M.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%2
M7U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N
M9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W
M=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D
M("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U
M<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D
M("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU
M;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE
M7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE
M(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D
M9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F
M<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A
M9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B
M7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ
M92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@
M/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L
M;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T
M96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B
M)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M
M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N
M=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N
M86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@
M(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D
M=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@
M)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=
M.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E
M;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M
M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92![
M"FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?
M4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O
M9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P
M<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@
M<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L
M:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY
M("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II
M9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D
M<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET
M("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@
M97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%
M35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA
M;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@
M;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E
M>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92([
M"GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D
M14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R
M;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_
M($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@
M5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N
M86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[
M7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS
M=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]
M*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,
M25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT[
M"GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6
M>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@
M)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@
M>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U
M<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<
M;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R![
M"G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P
M("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E
M>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O
M<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI
M9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R
M9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D
M<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S
M<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@
M:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`
M.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@
M:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I
M+F,`````0T%#2$4``#X```!!````#````$$````1````00```"<```!!````
M-@```$$````#````00````8```!!````%0```$$````/````00````X```!!
M````)@```$$````3````00```"D```!!`````@```$$````9````00````H`
M``!!````"P```$$``````````````/2*_W\!````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````M!@``$P8```!````(P,```$````S`P```0``
M`#T#```,````G!$```T```!<2@``&0```,"=```;````!````!H```#$G0``
M'`````0```#U_O]OK`$```4````8"0``!@```)@"```*````L@0```L````0
M````%0`````````#````T)X```(```#8`0``%````!$````7````Q`\``!$`
M``#L#@``$@```-@````3````"````!X````(````^___;P$```C^__]OG`X`
M`/___V\"````\/__;\H-``#Z__]O#@``````````````````````````````
M``````````````````````````#(G0````````````"H$0``J!$``*@1``"H
M$0``J!$``*@1``"H$0``J!$``*@1``"H$0``J!$``*@1``"H$0``J!$``*@1
M``"H$0``J!$``*@1``"H$0``J!$``*@1``"H$0``J!$``*@1``"H$0``J!$`
M`*@1``"H$0``J!$``*@1``"H$0``J!$``*@1``"H$0``J!$``*@1``"H$0``
MJ!$``*@1``"H$0``J!$``*@1``"H$0``J!$``*@1``"H$0``J!$``*@1``"H
M$0``J!$``*@1``"H$0``J!$``*@1``"H$0``J!$``*@1``"H$0``J!$`````
M``````````````````````````````````````````````````"`%```````
M``````````````````2@```*4$%2+G!M"@````!`3@``5$L````````43```
M&$P``#1.``!<2P``/$X````````@3@``*$X```````!(3@``1T-#.B`H1&5B
M:6%N(#$S+C(N,"TQ.2D@,3,N,BXP`$$J````865A8FD``2`````%-51%``8$
M"`$)`1($$P$4`14!%P,8`1D!&@(`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N
M9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`
M+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-+F5X:61X
M`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N
M9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````
M````````````````````````````````````````````````"P````$````"
M````5`$``%0!```3```````````````!`````````!,````'`````@```&@!
M``!H`0``)```````````````!``````````F````!P````(```",`0``C`$`
M`"````````````````0`````````-````/;__V\"````K`$``*P!``#L````
M!0`````````$````!````#X````+`````@```)@"``"8`@``@`8```8````#
M````!````!````!&`````P````(````8"0``&`D``+($``````````````$`
M````````3@```/___V\"````R@T``,H-``#0````!0`````````"`````@``
M`%L```#^__]O`@```)P.``"<#@``4`````8````"````!`````````!J````
M"0````(```#L#@``[`X``-@````%``````````0````(````<P````D```!"
M````Q`\``,0/``#8`0``!0```!4````$````"````'P````!````!@```)P1
M``"<$0``#```````````````!`````````!W`````0````8```"H$0``J!$`
M`-@"``````````````0````$````@@````$````&````@!0``(`4``#<-0``
M```````````0`````````(@````!````!@```%Q*``!<2@``"```````````
M````!`````````".`````0````(```!D2@``9$H``/A!``````````````0`
M````````E@````$``'""````7(P``%R,```(````#0`````````$````````
M`*$````!`````@```&2,``!DC```!```````````````!`````````"K````
M#@````,```#`G0``P(T```0```````````````0````$````MP````\````#
M````Q)T``,2-```$```````````````$````!````,,````&`````P```,B=
M``#(C0``"`$```8`````````!`````@```#,`````0````,```#0G@``T(X`
M`#`!``````````````0````$````T0````$````#`````*````"0``!(````
M```````````$`````````-<````(`````P```$B@``!(D```%```````````
M````!`````````#<`````0```#``````````2)```!\```````````````$`
M```!````Y0````,``'```````````&>0```K```````````````!````````
I``$````#``````````````"2D```]0```````````````0``````````
